.. include:: ../README.rst

.. figure:: images/logo.svg
    :align: center

    A cliquet, or ratchet, is a mechanical device that allows continuous linear
    or rotary motion in only one direction while preventing motion in the
    opposite direction.

    A cliquet provides some basic but essential functionality — efficient in a
    variety of contexts, from bikes rear wheels to most advanced clockmaking!


Table of content
================

.. toctree::
   :maxdepth: 1

   rationale
   quickstart
   api/index
   reference/index
   ecosystem
   contributing
   changelog
   contributors


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
